==> dice-0.1.1-57-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-CiMXWYSwygD5sXrGXDVzrA
key:                  dice-0.1.1-CiMXWYSwygD5sXrGXDVzrA
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  2d762a406b041fe514459a623f0d1102
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-CiMXWYSwygD5sXrGXDVzrA
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.2-IN7ymD0AKvltzeAmi6gkc
    random-fu-0.3.0.1-3qM9YPokROZLTpXuAQOjAh

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dice-0.1.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-CTCpM8eoA9mAVpO0vgsOkm
key:                  dice-0.1.1-CTCpM8eoA9mAVpO0vgsOkm
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  b5d1ccb727b5702e571c4c7b565e6cf8
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-CTCpM8eoA9mAVpO0vgsOkm
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    random-fu-0.3.0.1-9tu5L2GbNigKecCi79s8k

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
